#!/bin/bash 
INSTALLDIR=/usr/local/pulse
LOG=$INSTALLDIR/postinstall.log
# Redirect the stdout/stderr into postinstall log
echo "Starting Post Install Script " > $LOG
# no-same-owner is required to get root permission
tar --no-same-owner -xvzf /usr/local/pulse/pulse.tgz -C /usr/local/pulse >/dev/null
chmod +rws /usr/local/pulse/pulsesvc
PACKAGE_TYPE_RPM=1
PACKAGE_TYPE_DEB=2
SCRNAME=`basename $0`
readMeEchoMsg="Please refer /usr/local/pulse/README for instructions to launch the Pulse Client"
if [ "X$SCRNAME" = "XConfigurePulse.sh" ]; then 
    PKG=$PACKAGE_TYPE_RPM
else
    PKG=$PACKAGE_TYPE_DEB
    UNINSTALL=`echo $SCRNAME | grep -i prerm`
    if [ "X$UNINSTALL" != "X" ]; then 
        rm -f /usr/local/pulse/* 
        rmdir /usr/local/pulse
        exit 
    fi 
    chown $USER: /usr/local/pulse/PulseClient.sh
    chown $USER: /usr/local/pulse/version.txt
    chown $USER: /usr/local/pulse/pulse.tgz
fi
if [ $PKG = $PACKAGE_TYPE_RPM ]; then 
    PKGREQ=""
    glibc=`rpm -qa | grep -i glibc | grep -i "i686\|i386"`
    if [ "X$glibc" = "X" ]; then
        echo "glibc is missing in the machine" > $LOG
        PKGREQ="glibc"
    fi 
    nss=`rpm -qa | grep -i nss-softokn-freebl | grep -i "i386\|i686"`
    if [ "X$nss" = "X" ]; then 
        echo "nss is missing in the machine" > $LOG
        PKGREQ="$PKGREQ nss"
    fi
    zlib=`rpm -qa | grep -i zlib | grep -i "i386\|i686"`
    if [ "X$zlib" = "X" ]; then 
        echo "zlib is missing in the machine" > $LOG
        PKGREQ="$PKGREQ zlib"
    fi 
    if [ "X" != "X$PKGREQ" ]; then
        uname -a | grep -i "i386\|i486\|i586\|i686" >/dev/null
        if [ $? -ne 0 ]; then
        # Install respective packages based on the current installation
        echo " Please execute below commands to install missing dependent packages "
        for i in `echo $PKGREQ`
        do 
            echo "yum install $i"
        done
        fi 
    fi
    echo $readMeEchoMsg
    echo ""
elif [ $PKG = $PACKAGE_TYPE_DEB ]; then
    PKGREQ=""
    libc=`dpkg-query -f '${binary:Package}\n' -W | grep -i libc6-i386`
    if [ "X$libc" = "X" ]; then 
        PKGREQ="libc6-i386"
    fi
    zlib=`dpkg-query -f '${binary:Package}\n' -W | grep -i lib32z1`
    if [ "X$zlib" = "X" ]; then 
        PKGREQ="$PKGREQ lib32z1"
    fi
    if [ "X$PKGREQ" != "X" ]; then 
        uname -a | grep -i "i386\|i486\|i586\|i686"   >/dev/null
        if [ $? -ne 0 ]; then
        echo " Please execute below commands to install missing dependent packages "
        for i in `echo $PKGREQ`
        do 
            echo "apt-get install $i"
        done
        fi 
    fi 
    echo $readMeEchoMsg
    echo ""
fi

